@@ -174,19 +174,19 @@ class Normalise:
                 error_file.write(
                     str(rules[j]["column"]) + " mismatch row " + str(i) + " - " + str(value) + "\n")
 
-            if verbose == "to_console":
+            if verbose == "to_console" or "verbose" in rules[j] == False:
                 print(str(rules[j]["column"]) +
                       " mismatch row " + str(i) + " - " + str(value))
 
-        # Loop through all rules
-        j = -1
-        while j < len(rules):
-            j += 1
-            if j >= len(rules):
-                break
-
-            # Global rules, apply to all columns
+        def find_global_rules(j, rules):
             if not ("column" in rules[j]):
+                nonlocal global_check_coverage
+                nonlocal reset_coverage
+                nonlocal global_action
+                nonlocal global_verbose
+                nonlocal global_mapping
+                nonlocal dataframe
+
                 if "check_coverage" in rules[j]:
                     global_check_coverage = rules[j]["check_coverage"]
 
@@ -207,12 +207,28 @@ class Normalise:
                 if ("mapping" in rules[j]):
                     global_mapping = rules[j]["mapping"]
 
+                # Continue with next rule
+                return True
+
+            # No global rules found
+            return False
+
+        # Loop through all rules
+        j = -1
+        while j < len(rules):
+            # We're starting at -1 so j increment is at the top of the while loop
+            j += 1
+            if j >= len(rules):
+                break
+
+            if find_global_rules(j, rules) is True:
                 continue
 
             # Column not found in dataset
             try:
                 column_values = dataframe[rules[j]["column"]]
             except KeyError:
+                print("Column " + rules[j]["column"] + " not found")
                 continue
 
             if "mapping" in rules[j] or global_mapping != False:
@@ -237,6 +253,12 @@ class Normalise:
                         column_values = column_values.sample(
                             frac=int(check_coverage) / 100)
 
+            if "one_hot_encoding" in rules[j]:
+                if len(rules[j]["one_hot_encoding"]) == 0:
+                    dataframe = dataframe.join(pd.get_dummies(dataframe[rules[j]["column"]]))
+                else:
+                    dataframe = dataframe.join(pd.get_dummies(dataframe[rules[j]["column"]], prefix=rules[j]["one_hot_encoding"]))
+
             if "selection" in rules[j]:
                 sorted_selection = sorted(rules[j]["selection"])
                 for i, value in column_values.items():
@@ -249,6 +271,11 @@ class Normalise:
                     if not re.match(rules[j]["regex"], str(value)):
                         handle_mismatch(i, value, column_values)
 
+            if "range" in rules[j]:
+                for i, value in column_values.items():
+                    if not (float(rules[j]["range"][0]) <= float(value) <= float(rules[j]["range"][1])):
+                        handle_mismatch(i, value, column_values)
+
             if "type" in rules[j]:
 
                 if rules[j]["type"] == "percentage":
